@@ -13,6 +13,7 @@
 
 #include <QApplication>
 #include <QClipboard>
+#include <kwidgetsaddons_version.h>
 
 using namespace Akonadi;
 
@@ -171,21 +172,29 @@ void CalendarClipboard::cutIncidence(const KCalendarCore::Incidence::Ptr &incide
 {
     const bool hasChildren = !d->m_calendar->childIncidences(incidence->uid()).isEmpty();
     if (mode == AskMode && hasChildren) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const int km = KMessageBox::questionTwoActionsCancel(nullptr,
+#else
         const int km = KMessageBox::questionYesNoCancel(nullptr,
-                                                        i18n("The item \"%1\" has sub-to-dos. "
-                                                             "Do you want to cut just this item and "
-                                                             "make all its sub-to-dos independent, or "
-                                                             "cut the to-do with all its sub-to-dos?",
-                                                             incidence->summary()),
-                                                        i18n("KOrganizer Confirmation"),
-                                                        KGuiItem(i18n("Cut Only This")),
-                                                        KGuiItem(i18n("Cut All")));
+#endif
+                                                             i18n("The item \"%1\" has sub-to-dos. "
+                                                                  "Do you want to cut just this item and "
+                                                                  "make all its sub-to-dos independent, or "
+                                                                  "cut the to-do with all its sub-to-dos?",
+                                                                  incidence->summary()),
+                                                             i18nc("@title:window", "KOrganizer Confirmation"),
+                                                             KGuiItem(i18n("Cut Only This")),
+                                                             KGuiItem(i18n("Cut All")));
 
         if (km == KMessageBox::Cancel) {
             Q_EMIT cutFinished(/*success=*/true, QString());
             return;
         }
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        mode = km == KMessageBox::ButtonCode::PrimaryAction ? SingleMode : RecursiveMode;
+#else
         mode = km == KMessageBox::Yes ? SingleMode : RecursiveMode;
+#endif
     } else if (mode == AskMode) {
         mode = SingleMode; // Doesn't have children, don't ask
     }
@@ -211,18 +220,26 @@ bool CalendarClipboard::copyIncidence(const KCalendarCore::Incidence::Ptr &incid
 {
     const bool hasChildren = !d->m_calendar->childIncidences(incidence->uid()).isEmpty();
     if (mode == AskMode && hasChildren) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const int km = KMessageBox::questionTwoActionsCancel(nullptr,
+#else
         const int km = KMessageBox::questionYesNoCancel(nullptr,
-                                                        i18n("The item \"%1\" has sub-to-dos. "
-                                                             "Do you want to copy just this item or "
-                                                             "copy the to-do with all its sub-to-dos?",
-                                                             incidence->summary()),
-                                                        i18n("KOrganizer Confirmation"),
-                                                        KGuiItem(i18n("Copy Only This")),
-                                                        KGuiItem(i18n("Copy All")));
+#endif
+                                                             i18n("The item \"%1\" has sub-to-dos. "
+                                                                  "Do you want to copy just this item or "
+                                                                  "copy the to-do with all its sub-to-dos?",
+                                                                  incidence->summary()),
+                                                             i18nc("@title:window", "KOrganizer Confirmation"),
+                                                             KGuiItem(i18n("Copy Only This")),
+                                                             KGuiItem(i18n("Copy All")));
         if (km == KMessageBox::Cancel) {
             return true;
         }
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        mode = km == KMessageBox::ButtonCode::PrimaryAction ? SingleMode : RecursiveMode;
+#else
         mode = km == KMessageBox::Yes ? SingleMode : RecursiveMode;
+#endif
     } else if (mode == AskMode) {
         mode = SingleMode; // Doesn't have children, don't ask
     }
