@@ -6,7 +6,7 @@
 */
 
 #include "calfilterproxymodel_p.h"
-#include "utils_p.h"
+#include "calendarutils.h"
 
 #include <Akonadi/EntityTreeModel>
 #include <Akonadi/Item>
@@ -19,9 +19,7 @@ using namespace Akonadi;
 class Akonadi::CalFilterProxyModelPrivate
 {
 public:
-    explicit CalFilterProxyModelPrivate()
-    {
-    }
+    explicit CalFilterProxyModelPrivate() = default;
 
     KCalendarCore::CalFilter *filter = nullptr;
 };
