@@ -25,7 +25,6 @@
 #include <KMessageBox>
 
 #include <KIO/Job>
-#include <KIO/JobUiDelegate>
 #include <KLocalizedString>
 #include <QUrl>
 
@@ -373,9 +372,9 @@ void FreeBusyManagerPrivate::processFreeBusyDownloadResult(KJob *_job)
     Q_ASSERT(job);
     if (job->error()) {
         qCritical() << "Error downloading freebusy" << _job->errorString();
-        KMessageBox::sorry(mParentWidgetForRetrieval,
+        KMessageBox::error(mParentWidgetForRetrieval,
                            i18n("Failed to download free/busy data from: %1\nReason: %2", job->url().toDisplayString(), job->errorText()),
-                           i18n("Free/busy retrieval error"));
+                           i18nc("@title:window", "Free/Busy Retrieval Error"));
 
         // TODO: Ask for a retry? (i.e. queue  the email again when the user wants it).
 
@@ -396,9 +395,9 @@ void FreeBusyManagerPrivate::processFreeBusyDownloadResult(KJob *_job)
             Q_EMIT q->freeBusyRetrieved(fb, email);
         } else {
             qCritical() << "Error downloading freebusy, invalid fb.";
-            KMessageBox::sorry(mParentWidgetForRetrieval,
+            KMessageBox::error(mParentWidgetForRetrieval,
                                i18n("Failed to parse free/busy information that was retrieved from: %1", job->url().toDisplayString()),
-                               i18n("Free/busy retrieval error"));
+                               i18nc("@title:window", "Free/Busy Retrieval Error"));
         }
     }
 
@@ -411,7 +410,7 @@ void FreeBusyManagerPrivate::processFreeBusyUploadResult(KJob *_job)
 {
     auto job = static_cast<KIO::FileCopyJob *>(_job);
     if (job->error()) {
-        KMessageBox::sorry(nullptr,
+        KMessageBox::error(nullptr,
                            i18n("<qt><p>The software could not upload your free/busy list to "
                                 "the URL '%1'. There might be a problem with the access "
                                 "rights, or you specified an incorrect URL. The system said: "
@@ -614,7 +613,7 @@ void FreeBusyManagerPrivate::processMailSchedulerResult(Akonadi::Scheduler::Resu
     if (result == Scheduler::ResultSuccess) {
         KMessageBox::information(mParentWidgetForMailling,
                                  i18n("The free/busy information was successfully sent."),
-                                 i18n("Sending Free/Busy"),
+                                 i18nc("@title:window", "Sending Free/Busy"),
                                  QStringLiteral("FreeBusyPublishSuccess"));
     } else {
         KMessageBox::error(mParentWidgetForMailling, i18n("Unable to publish the free/busy data: %1", errorMsg));
@@ -740,13 +739,13 @@ void FreeBusyManager::publishFreeBusy(QWidget *parentWidget)
 
     QUrl targetURL(CalendarSettings::self()->freeBusyPublishUrl());
     if (targetURL.isEmpty()) {
-        KMessageBox::sorry(parentWidget,
+        KMessageBox::error(parentWidget,
                            i18n("<qt><p>No URL configured for uploading your free/busy list. "
                                 "Please set it in KOrganizer's configuration dialog, on the "
                                 "\"Free/Busy\" page.</p>"
                                 "<p>Contact your system administrator for the exact URL and the "
                                 "account details.</p></qt>"),
-                           i18n("No Free/Busy Upload URL"));
+                           i18nc("@title:window", "No Free/Busy Upload URL"));
         return;
     }
 
@@ -755,7 +754,7 @@ void FreeBusyManager::publishFreeBusy(QWidget *parentWidget)
         return;
     }
     if (!targetURL.isValid()) {
-        KMessageBox::sorry(parentWidget, i18n("<qt>The target URL '%1' provided is invalid.</qt>", targetURL.toDisplayString()), i18n("Invalid URL"));
+        KMessageBox::error(parentWidget, i18n("<qt>The target URL '%1' provided is invalid.</qt>", targetURL.toDisplayString()), i18nc("@title:window", "Invalid URL"));
         d->mBrokenUrl = true;
         return;
     }
