@@ -7,7 +7,6 @@
 */
 
 #include "icalimporter.h"
-#include "akonadicalendar_debug.h"
 #include "icalimporter_p.h"
 #include "utils_p.h"
 
@@ -20,6 +19,7 @@
 #include <KIO/Job>
 
 #include <QDBusInterface>
+#include <QFileInfo>
 #include <QTemporaryFile>
 #include <QTimeZone>
 
@@ -173,8 +173,9 @@ bool ICalImporter::importIntoExistingResource(const QUrl &url, Collection collec
     }
 
     if (url.isLocalFile()) {
-        if (!QFile::exists(url.path())) {
-            d->setErrorMessage(i18n("The specified file doesn't exist, aborting import."));
+        QFileInfo f{url.path()};
+        if (!f.exists() || !f.isFile() || !f.isReadable()) {
+            d->setErrorMessage(i18n("The selected file is not a readable file."));
             return false;
         }
         MemoryCalendar::Ptr temporaryCalendar(new MemoryCalendar(QTimeZone::systemTimeZone()));
@@ -182,7 +183,7 @@ bool ICalImporter::importIntoExistingResource(const QUrl &url, Collection collec
         storage.setFileName(url.path());
         bool success = storage.load();
         if (!success) {
-            d->setErrorMessage(i18n("Failed to load ical file, check permissions."));
+            d->setErrorMessage(i18n("The selected file is not properly formatted, or in a format not supported by this software."));
             return false;
         }
 
@@ -190,7 +191,7 @@ bool ICalImporter::importIntoExistingResource(const QUrl &url, Collection collec
         const Incidence::List incidences = temporaryCalendar->incidences();
 
         if (incidences.isEmpty()) {
-            d->setErrorMessage(i18n("The ical file to merge is empty."));
+            d->setErrorMessage(i18n("The selected file is empty."));
             return false;
         }
 
