@@ -5,7 +5,6 @@
 */
 
 #include "itiphandler_p.h"
-#include "akonadicalendar_debug.h"
 #include "fetchjobcalendar.h"
 #include <KCalendarCore/Incidence>
 #include <KLocalizedString>
@@ -134,7 +133,7 @@ void ITIPHandlerPrivate::finishSendiTIPMessage(Akonadi::MailScheduler::Result re
                                           "was successfully sent.\nMethod: %2",
                                           m_queuedInvitation.incidence->summary(),
                                           KCalendarCore::ScheduleMessage::methodName(m_queuedInvitation.method)),
-                                     i18n("Sending Free/Busy"),
+                                     i18nc("@title:window", "Sending Free/Busy"),
                                      QStringLiteral("FreeBusyPublishSuccess"));
         }
         Q_EMIT q->iTipMessageSent(ITIPHandler::ResultSuccess, QString());
@@ -159,7 +158,7 @@ void ITIPHandlerPrivate::finishPublishInformation(Akonadi::MailScheduler::Result
         if (m_parentWidget) {
             KMessageBox::information(m_parentWidget,
                                      i18n("The item information was successfully sent."),
-                                     i18n("Publishing"),
+                                     i18nc("@title:window", "Publishing"),
                                      QStringLiteral("IncidencePublishSuccess"));
         }
         Q_EMIT q->informationPublished(ITIPHandler::ResultSuccess, QString());
@@ -179,13 +178,13 @@ void ITIPHandlerPrivate::finishSendAsICalendar(Akonadi::MailClient::Result resul
         if (m_parentWidget) {
             KMessageBox::information(m_parentWidget,
                                      i18n("The item information was successfully sent."),
-                                     i18n("Forwarding"),
+                                     i18nc("@title:window", "Forwarding"),
                                      QStringLiteral("IncidenceForwardSuccess"));
         }
         Q_EMIT q->sentAsICalendar(ITIPHandler::ResultSuccess, QString());
     } else {
         if (m_parentWidget) {
-            KMessageBox::error(m_parentWidget, i18n("Unable to forward the item '%1'", m_queuedInvitation.incidence->summary()), i18n("Forwarding Error"));
+            KMessageBox::error(m_parentWidget, i18n("Unable to forward the item '%1'", m_queuedInvitation.incidence->summary()), i18nc("@title:window", "Forwarding Error"));
         }
         qCritical() << "Sent as iCalendar failed." << errorMessage;
         Q_EMIT q->sentAsICalendar(ITIPHandler::ResultError, errorMessage);
@@ -210,7 +209,7 @@ bool ITIPHandlerPrivate::isLoaded()
 {
     FetchJobCalendar::Ptr fetchJobCalendar = calendar().dynamicCast<Akonadi::FetchJobCalendar>();
     if (fetchJobCalendar) {
-        return fetchJobCalendar->isLoaded();
+        return !fetchJobCalendar->isLoading();
     }
 
     // If it's an ETMCalendar, set through setCalendar(), then it's already loaded, it's a requirement of setCalendar().
