@@ -16,11 +16,11 @@
 #include <KCalendarCore/Attendee>
 #include <KCalendarCore/Incidence>
 #include <KEmailAddress>
-#include <identity.h>
+#include <KIdentityManagement/Identity>
 
-#include <messagequeuejob.h>
-#include <transport.h>
-#include <transportmanager.h>
+#include <MailTransport/Transport>
+#include <MailTransport/TransportManager>
+#include <MailTransportAkonadi/MessageQueueJob>
 
 #include "akonadicalendar_debug.h"
 #include <KJob>
@@ -35,9 +35,7 @@ MailClient::MailClient(ITIPHandlerComponentFactory *factory, QObject *parent)
 {
 }
 
-MailClient::~MailClient()
-{
-}
+MailClient::~MailClient() = default;
 
 void MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidence,
                                const KIdentityManagement::Identity &identity,
