@@ -13,7 +13,7 @@
 
 #include <KCalendarCore/Person>
 
-#include <KCodecs/KEmailAddress>
+#include <KEmailAddress>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -28,7 +28,7 @@ using namespace Akonadi;
 
 PublishDialog::PublishDialog(QWidget *parent)
     : QDialog(parent)
-    , d(new Private(this))
+    , d(new PublishDialogPrivate(this))
 {
     setWindowTitle(i18nc("@title:window", "Select Addresses"));
     auto layout = new QVBoxLayout(this);
@@ -44,12 +44,12 @@ PublishDialog::PublishDialog(QWidget *parent)
     d->mUI.mRemove->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
     d->mUI.mRemove->setEnabled(false);
     d->mUI.mSelectAddressee->setIcon(QIcon::fromTheme(QStringLiteral("view-pim-contacts")));
-    connect(d->mUI.mListWidget, &QListWidget::itemSelectionChanged, d, &Private::updateInput);
-    connect(d->mUI.mNew, &QAbstractButton::clicked, d, &Private::addItem);
-    connect(d->mUI.mRemove, &QAbstractButton::clicked, d, &Private::removeItem);
-    connect(d->mUI.mSelectAddressee, &QAbstractButton::clicked, d, &Private::openAddressbook);
-    connect(d->mUI.mNameLineEdit, &QLineEdit::textChanged, d, &Private::updateItem);
-    connect(d->mUI.mEmailLineEdit, &QLineEdit::textChanged, d, &Private::updateItem);
+    connect(d->mUI.mListWidget, &QListWidget::itemSelectionChanged, d.get(), &PublishDialogPrivate::updateInput);
+    connect(d->mUI.mNew, &QAbstractButton::clicked, d.get(), &PublishDialogPrivate::addItem);
+    connect(d->mUI.mRemove, &QAbstractButton::clicked, d.get(), &PublishDialogPrivate::removeItem);
+    connect(d->mUI.mSelectAddressee, &QAbstractButton::clicked, d.get(), &PublishDialogPrivate::openAddressbook);
+    connect(d->mUI.mNameLineEdit, &QLineEdit::textChanged, d.get(), &PublishDialogPrivate::updateItem);
+    connect(d->mUI.mEmailLineEdit, &QLineEdit::textChanged, d.get(), &PublishDialogPrivate::updateItem);
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -79,10 +79,7 @@ PublishDialog::PublishDialog(QWidget *parent)
     connect(buttonBox->button(QDialogButtonBox::Help), &QPushButton::clicked, this, &PublishDialog::slotHelp);
 }
 
-PublishDialog::~PublishDialog()
-{
-    delete d;
-}
+PublishDialog::~PublishDialog() = default;
 
 void PublishDialog::slotHelp()
 {
@@ -121,11 +118,11 @@ void PublishDialog::accept()
     QString badAddress;
     const KEmailAddress::EmailParseResult addressOk = KEmailAddress::isValidAddressList(addresses(), badAddress);
     if (addressOk != KEmailAddress::AddressOk) {
-        KMessageBox::sorry(this,
+        KMessageBox::error(this,
                            i18n("Unable to publish the calendar incidence due to an "
                                 "invalid recipients string. %1",
                                 emailParseResultToString(addressOk)),
-                           i18n("Publishing Error"));
+                           i18nc("@title:window", "Publishing Error"));
     } else {
         QDialog::accept();
     }
